#!/bin/bash

#  sign-for-sparkle.sh
#  iRed2
#
#  Created by Robert Fischer on 13.01.12.
#  Copyright (c) 2012 tin:b Software. All rights reserved.

set -o errexit

[ $BUILD_STYLE = Release ] || { echo Distribution target requires "'Release'" build style; false; }

VERSION=$(defaults read "$BUILT_PRODUCTS_DIR/$PROJECT_NAME.app/Contents/Info" CFBundleVersion)
DOWNLOAD_BASE_URL="http://www.tinbert.com/download/"
RELEASENOTES_URL_EN="http://www.tinbert.com/sparkle/release-notes-ired2-en.html"
RELEASENOTES_URL_DE="http://www.tinbert.com/sparkle/release-notes-ired2-de.html"

ARCHIVE_FILENAME="$PROJECT_NAME_$VERSION.zip"
DOWNLOAD_URL="$DOWNLOAD_BASE_URL/$ARCHIVE_FILENAME"
KEYCHAIN_PRIVKEY_NAME="SparklePrivateKey"

WD=$PWD
cd "$BUILT_PRODUCTS_DIR"
## rm -f "$PROJECT_NAME"*.zip
ditto -ck --keepParent "$PROJECT_NAME.app" "$ARCHIVE_FILENAME"

SIZE=$(stat -f %z "$ARCHIVE_FILENAME")
PUBDATE=$(LC_TIME=en_US date +"%a, %d %b %G %T %z")
SIGNATURE=$(
	openssl dgst -sha1 -binary < "$ARCHIVE_FILENAME" \
	| openssl dgst -dss1 -sign <(security find-generic-password -g -s "$KEYCHAIN_PRIVKEY_NAME" 2>&1 1>/dev/null | perl -pe '($_) = /"(.+)"/; s/\\012/\n/g') \
	| openssl enc -base64
)

[ $SIGNATURE ] || { echo Unable to load signing private key with name "'$KEYCHAIN_PRIVKEY_NAME'" from keychain; false; }

cat <<EOF
		<item>
			<title>Version $VERSION</title>
			<sparkle:releaseNotesLink xml:lang="en">$RELEASENOTES_URL_EN</sparkle:releaseNotesLink>
			<sparkle:releaseNotesLink xml:lang="de">$RELEASENOTES_URL_DE</sparkle:releaseNotesLink>
			<pubDate>$PUBDATE</pubDate>
			<enclosure
				url="$DOWNLOAD_URL"
				sparkle:version="$VERSION"
				type="application/octet-stream"
				length="$SIZE"
				sparkle:dsaSignature="$SIGNATURE"
			/>
		</item>
EOF

##echo scp "'$HOME/svn/my-cool-app/build/Release/$ARCHIVE_FILENAME'" www.example.com:download/
##echo scp "'$WD/appcast.xml'" www.example.com:web/software/my-cool-app/appcast.xml